#########
ROMSearch
#########

This is the main part that controls the various other modules. It essentially calls everything (given user preferences),
and so while it doesn't really do all that much on its own, is the interface to everything else.

For more details on the ROMSearch arguments, see the :doc:`config file documentation <../configs/config>`.

API
===

.. autoclass:: romsearch.ROMSearch
    :no-index:
    :members:
    :undoc-members:
